@@ -55,7 +55,7 @@ class Config:
         config_dir, self.data_dir = self.get_user_directories()
         self.filename = os.path.join(config_dir, "config")
         self.plugin_dir = os.path.join(self.data_dir, "plugins")
-        self.version = "3.2.6"
+        self.version = "3.2.8"
         self.python_version = sys.version
         self.gtk_version = ""
 
@@ -63,7 +63,7 @@ class Config:
         self.application_id = "org.nicotine_plus.Nicotine"
         self.summary = _("Graphical client for the Soulseek peer-to-peer network")
         self.author = "Nicotine+ Team"
-        self.copyright = """© 2004–2022 Nicotine+ Contributors
+        self.copyright = """© 2004–2023 Nicotine+ Contributors
 © 2003–2004 Nicotine Contributors
 © 2001–2003 PySoulSeek Contributors"""
 
@@ -552,10 +552,6 @@ class Config:
             )
         }
 
-        # Windows specific stuff
-        if sys.platform == "win32":
-            self.defaults['players']['npplayer'] = 'other'
-
         # Initialize config with default values
         for key, value in self.defaults.items():
             self.sections[key] = value.copy()
@@ -754,6 +750,9 @@ class Config:
                 self.parser.add_section(section)
 
             for option, value in options.items():
+                if value is None:
+                    value = ""
+
                 self.parser.set(section, option, str(value))
 
         # Remove legacy config options
